@@ -1,9 +1,8 @@
 import os
-import socket
 import logging
-
 from ..connector import Connector
 
+
 class Server(Connector):
     """UNIX-socket server used to communicate with clients."""
     def __init__(self):
@@ -28,11 +27,20 @@ class Server(Connector):
             return True
         except OSError as e:
             logging.error('Failed to create UNIX socket: %s' % e.strerror)
-        
+
         return False
 
     def close(self):
         """Unbinds the socket and deletes the file."""
         self.socket.close()
-        os.remove(self.host)
 
+        try:
+            """
+            UNIX-sockets can be overwritten by other processes even if another process
+            is already using it. This may lead to the file not existing and will
+            cause a crash if not handled properly.
+            """
+            os.remove(self.host)
+            logging.debug('UNIX-socket deleted')
+        except OSError as e:
+            logging.debug('UNIX-socket has already been deleted, skipping')
